@@ -567,6 +567,8 @@ impl TryFrom<tx_by_addr::TransactionError> for TransactionError {
             18 => TransactionError::UnsupportedVersion,
             19 => TransactionError::InvalidWritableAccount,
             20 => TransactionError::WouldExceedMaxAccountCostLimit,
+            21 => TransactionError::WouldExceedMaxAccountDataCostLimit,
+            22 => TransactionError::TooManyAccountLocks,
             _ => return Err("Invalid TransactionError"),
         })
     }
@@ -637,6 +639,12 @@ impl From<TransactionError> for tx_by_addr::TransactionError {
                 TransactionError::WouldExceedMaxAccountCostLimit => {
                     tx_by_addr::TransactionErrorType::WouldExceedMaxAccountCostLimit
                 }
+                TransactionError::WouldExceedMaxAccountDataCostLimit => {
+                    tx_by_addr::TransactionErrorType::WouldExceedMaxAccountDataCostLimit
+                }
+                TransactionError::TooManyAccountLocks => {
+                    tx_by_addr::TransactionErrorType::TooManyAccountLocks
+                }
             } as i32,
             instruction_error: match transaction_error {
                 TransactionError::InstructionError(index, ref instruction_error) => {
